History — bcselector 0.0.38 documentation

# History

## 0.0.36

> - Added sample dataset to work with and function to load it.

## 0.0.35

> - Added MANIFEST.in file.

## 0.0.32

> - Fixed return type of target for hepatitis dataset.

## 0.0.31

> - Add buildin data: hepatitis and function to load them.

## 0.0.30

> - Add first complete version of documenation and quickstart in README.

> - Small fixes in variable_selection package. Spliting no-cost fix and score functions.

## 0.0.24

> - Add first version of documentation.

## 0.0.23

> - Fix filter_values to selection loop to be rounded.

> - Add discretization to data generation

## 0.0.22

> - Add filter_values to selection loop.

## 0.0.21

> - Add budget parameter to fit function.

> - Small fixes in criterion/filter values return.